(define banner #<<EOF

  ___| |    _)      |               
 |     __ \  |  __| |  /  _ \ __ \  
 |     | | | | (      <   __/ |   | 
\____|_| |_|_|\___|_|\_\\___|_|  _| 


EOF
)
